=== modified file 'bzrlib/mail_client.py'
--- bzrlib/mail_client.py	2009-01-05 16:04:45 +0000
+++ bzrlib/mail_client.py	2009-01-05 17:12:46 +0000
@@ -310,26 +310,21 @@
 
     def _get_compose_commandline(self, to, subject, attach_path):
         """See ExternalMailClient._get_compose_commandline"""
-        options = []
+        compose_url = ['mailto:']
+        if to is not None:
+            compose_url.append(self._encode_safe(to))
+        compose_url.append('?')
         if subject is not None:
-            options.append(
-                ('subject', self._encode_safe(subject)))
+            # Don't use urllib.quote_plus because Claws doesn't seem
+            # to recognise spaces encoded as "+".
+            compose_url.append(
+                'subject=%s' % urllib.quote(self._encode_safe(subject)))
+        # Collect command-line options.
+        message_options = ['--compose', ''.join(compose_url)]
         if attach_path is not None:
-            options.append(
-                ('attach', self._encode_path(attach_path, 'attachment')))
-        if self.config is not None:
-            username = self.config.username()
-            if username is not None:
-                options.append(
-                    ('from', self._encode_safe(username)))
-        # Doesn't use urllib.urlencode because it uses quote_plus, and
-        # Claws doesn't seem to recognise spaces encoded as "+".
-        option_string = '&'.join(
-            '%s=%s' % (urllib.quote(key), urllib.quote(value))
-            for (key, value) in options)
-        if to is None:
-            to = ''
-        return ['--compose', '%s?%s' % (self._encode_safe(to), option_string)]
+            message_options.extend(
+                ['--attach', self._encode_path(attach_path, 'attachment')])
+        return message_options
 mail_client_registry.register('claws', Claws,
                               help=Claws.__doc__)
 

=== modified file 'bzrlib/tests/test_mail_client.py'
--- bzrlib/tests/test_mail_client.py	2009-01-05 16:04:55 +0000
+++ bzrlib/tests/test_mail_client.py	2009-01-05 17:12:46 +0000
@@ -187,27 +187,15 @@
 
     def test_commandline(self):
         claws = mail_client.Claws(None)
-        commandline = claws._get_compose_commandline(None, None, 'file%')
-        self.assertEqual(['--compose', '?attach=file%25'], commandline)
-        commandline = claws._get_compose_commandline(
-            'jrandom@example.org', 'Hi there!', None)
-        self.assertEqual(
-            ['--compose', 'jrandom@example.org?subject=Hi%20there%21'],
-            commandline)
-
-    def test_commandline_with_config(self):
-        claws = mail_client.Claws(InstrumentedConfig())
-        commandline = claws._get_compose_commandline(None, None, 'file%')
-        self.assertEqual(
-            ['--compose', ('?attach=file%25&from=Robert%20Collins%20'
-                           '%3Crobert.collins%40example.org%3E')],
-            commandline)
-        commandline = claws._get_compose_commandline(
-            'jrandom@example.org', 'Hi there!', None)
-        self.assertEqual(
-            ['--compose', ('jrandom@example.org?subject=Hi%20there%21'
-                           '&from=Robert%20Collins%20'
-                           '%3Crobert.collins%40example.org%3E')],
+        commandline = claws._get_compose_commandline(
+            None, None, 'file%')
+        self.assertEqual(
+            ['--compose', 'mailto:?', '--attach', 'file%'], commandline)
+        commandline = claws._get_compose_commandline(
+            'jrandom@example.org', 'Hi there!', None)
+        self.assertEqual(
+            ['--compose',
+             'mailto:jrandom@example.org?subject=Hi%20there%21'],
             commandline)
 
     def test_commandline_is_8bit(self):
@@ -216,7 +204,9 @@
             u'jrandom@example.org', u'Hi there!', u'file%')
         self.assertEqual(
             ['--compose',
-             'jrandom@example.org?subject=Hi%20there%21&attach=file%25'],
+             'mailto:jrandom@example.org?subject=Hi%20there%21',
+             '--attach',
+             'file%'],
             cmdline)
         for item in cmdline:
             self.assertFalse(isinstance(item, unicode),

